@@ -357,11 +357,6 @@ class Base(Controller):
                 "help" : "To show the full command if too long to fit in terminal",
                 "action" : "store"
             }),
-            (['-id'],{
-                # TODO: likely delete
-            "help" : "Which CLI snippet ID to run",
-            "action": "store"
-            }),
             (['-n'],{
                 # TODO: probably better as mandatory
                 "help" : "Which lines from the selected history to show/save",
@@ -370,6 +365,10 @@ class Base(Controller):
             (['-e'],{
                 "help": "Which terns to exclude separated by commas",
                 "action": "store"
+            }),
+            (['-a','--alias'],{
+                "help": "Name for the snippet.",
+                "action" : "store"
             })
         ]
     )
@@ -382,8 +381,15 @@ class Base(Controller):
             if isinstance(excluded_terms, str): excluded_terms = excluded_terms.split(',')
             pp.pprint(hist_tail(n_lines, excluded_terms))
         else:
-            from ..ext.hist import hist_show
-            print(hist_show(self.app.pargs.n))
+            from ..ext.hist import hist_save
+            import uuid
+            
+            n_lines = int(self.app.pargs.n or 20)
+            lines_to_save = [int(x) for x in str(self.app.pargs.s).split(',')]
+            snippet_name = self.app.pargs.__dict__.get('a') or self.app.pargs.__dict__.get('alias') or str(uuid.uuid4())
+            print(f'Saving {n_lines} lines from history to snippet {snippet_name}')
+            
+            hist_save(lines_to_save, snippet_name, n_lines=n_lines)
 
     @ex(
         help='Operations with snippets',
@@ -401,21 +407,40 @@ class Base(Controller):
                 # TODO: probably better as mandatory
                 "help" : "Which lines from the selected history to show/save",
                 "action" : "store"
-            })
+            }),
             # TODO: what if non-default n lines has been pased to hist
+            (['--save'],{
+                "help" : "Whether to save the snippet to the history",
+                # TODO: figure out if bool
+                "action" : "store"   
+            }),
+            (['--ls'],{
+                "help" : "Whether to list all snippets at different levels (0,1,2)",
+                "action" : "store"
+            })
         ]
     )
     def run(self):
-        from ..ext.run import run_command
-        n_lines = [int(x) for x in str(self.app.pargs.n).split(',')]
-        run_command(n_lines)
-
-
+        is_save = self.app.pargs.save or False
+        is_ls = self.app.pargs.ls or False
+        
+        if not is_save:
+            from ..ext.run import run_command
+            n_lines = [int(x) for x in str(self.app.pargs.n).split(',')]
+            run_command(n_lines)
+        if is_ls:
+            from ..ext.run import list_snippets
+            list_snippets(int(self.app.pargs.ls))
+        else:
+            from ..ext.run import save_command
+            n_lines = [int(x) for x in str(self.app.pargs.n).split(',')]
+            save_command(n_lines)
+            
     @ex(
         help='Operations with s3 bucket creationlabs-raw-data',
         arguments=[
             (['action'],{
-                "help" : "One of {ls, link, lsa}",
+                "help" : "One of {ls, link}",
                 "action" : "store"
             }),
             (['target'],{
@@ -490,7 +515,6 @@ class Base(Controller):
         from ..ext.sshconf import read_ssh_config
         ssh_config_path = os.path.expanduser('~/.ssh/config')
         from ..ext.sshconf import print_ls
-        
 
         if self.app.pargs.action=='set':
             ssh_config_obj = read_ssh_config(ssh_config_path)
@@ -564,25 +588,24 @@ class Base(Controller):
     )
     def config(self):
         # TODO: setup Data-toolkit specific config
-        args = self.app.pargs
-
         # shows config
-        if args.action=='show':
-            for attr in dir(config):
-                if not attr.startswith('_'):
-                    print(f"{attr}: {getattr(config,attr)}")
+        
+        if self.app.pargs.action=='show':
+            from ..ext.config import show_config
+            show_config()
 
         # shows the path of the config
-        if args.action=='loc':
-            print(os.path.abspath(__file__))
+        if self.app.pargs.action=='loc':
+            from ..ext.config import show_config_path
+            show_config_path()
 
         # resets the config
         # TODO this config method needs programmatic acces for spot instances
-        if args.action=='set':
+        if self.app.pargs.action=='set':
             from ..ext.tracking import initialize
             initialize(overwrite=True)
 
-        elif args.action not in ['set','loc', 'show']:
+        elif self.app.pargs.action not in ['set','loc', 'show']:
             raise NotImplementedError("Try one of {show, set, loc}")
 
 
